from http import HTTPStatus

RETRYABLE_STATUS_CODES = [
    HTTPStatus.TOO_MANY_REQUESTS,
    HTTPStatus.BAD_GATEWAY,
    HTTPStatus.SERVICE_UNAVAILABLE,
    HTTPStatus.GATEWAY_TIMEOUT,
]

MAX_RETRY_ATTEMPTS = 3
RETRY_BACKOFF_BASE = 2
